package Logic;

import java.awt.Dimension;
import java.awt.Point;
import java.awt.geom.Point2D;
import java.util.ArrayList;

public class MainLogic {

	private ArrayList<BaseShape> mAllShapes = new ArrayList<BaseShape>();
	
	Dimension mDimensions = new Dimension();
	
	public void SetSize(int width, int height) 
	{
		mDimensions = new Dimension(width, height);
	}

	public BaseShape CreateObject(Point tCenter, Point tLaunch) 
	{
		BaseShape tNew = new BaseShape();
		tNew.SetPosition( new Point2D.Float(tLaunch.x, tLaunch.y) );
		tNew.SetVelocity( new Point2D.Float(tCenter.x - tLaunch.x, tCenter.y - tLaunch.y) );
		mAllShapes.add(tNew);
		
		return tNew;
	}

	public void Update( float tDelta )
	{
		// To worry about the ones that fly off screen, we'd have to implement listening, and that's hard.
		for( BaseShape tOne: mAllShapes )
		{
			// Set the acceleration due to the sun, and kill the ones that touch it
			// To make gravity math easy, we can assume all circles are same mass and factor that out.
			// Important part that makes the cool curves is that force is inverse to square of distance
			double tDistance = tOne.GetPosition().distance((mDimensions.width / 2), (mDimensions.height / 2));
			if( tDistance > 0 && tDistance < 20 )
			{
				tOne.mIsDead = true;// hit the center dot
				continue;
			}
			double tMagnitude = tDelta / (tDistance * tDistance);
			
			Point2D.Float tSeparation = new Point2D.Float( (mDimensions.width / 2) - tOne.GetPosition().x, 
					(mDimensions.height / 2) - tOne.GetPosition().y);
			if( tDistance != 0 )
			{
				tSeparation.x /= tDistance; // normalize
				tSeparation.y /= tDistance;

				double FAKE_SUN_FORCE = 20000000.0f;
				tMagnitude *= FAKE_SUN_FORCE;
				tSeparation.x *= tMagnitude;// scale
				tSeparation.y *= tMagnitude;
			}
			
			tOne.SetAcceleration(tSeparation);
	
			tOne.Update(tDelta);
			// Super real cool mode is to have everything affect everything
		}
	}
}
